@@ -65,7 +65,7 @@ def built_date_diff(documents: List[MongoDocument], literal: Literal, unit: str)
 
 def build_literal(
 		documents: List[MongoDocument], literal: Literal, build_plain_value: Callable[[Any], str] = None
-) -> Union[str, Dict[str: Any]]:
+) -> Union[str, Dict[str, Any]]:
 	if isinstance(literal, ColumnNameLiteral):
 		# only one document is supported
 		return f'${literal.columnName}'
@@ -432,9 +432,9 @@ def build_criteria_expression(documents: List[MongoDocument], expression: Entity
 	elif op == EntityCriteriaOperator.GREATER_THAN_OR_EQUALS:
 		return {'$gte': [built_left, built_right]}
 	elif op == EntityCriteriaOperator.LIKE:
-		return {'$regexMatch': {'input': built_left, 'regexp': built_right}}
+		return {'$regexMatch': {'input': built_left, 'regex': built_right}}
 	elif op == EntityCriteriaOperator.NOT_LIKE:
-		return {'$not': {'$regexMatch': {'input': built_left, 'regexp': built_right}}}
+		return {'$not': {'$regexMatch': {'input': built_left, 'regex': built_right}}}
 	else:
 		raise UnsupportedCriteriaException(f'Unsupported criteria expression operator[{op}].')
 
@@ -444,7 +444,7 @@ def build_criteria_joint(documents: List[MongoDocument], joint: EntityCriteriaJo
 	if conjunction == EntityCriteriaJointConjunction.AND:
 		return {'$and': ArrayHelper(joint.children).map(lambda x: build_criteria_statement(documents, x)).to_list()}
 	elif conjunction == EntityCriteriaJointConjunction.OR:
-		return {'$or:': ArrayHelper(joint.children).map(lambda x: build_criteria_statement(documents, x)).to_list()}
+		return {'$or': ArrayHelper(joint.children).map(lambda x: build_criteria_statement(documents, x)).to_list()}
 	else:
 		raise UnsupportedCriteriaException(f'Unsupported criteria joint conjunction[{conjunction}].')
 
